summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Changelog-Trunk.txt1
-rw-r--r--src/map/battle.c2
-rw-r--r--src/map/clif.c15
-rw-r--r--src/map/clif.h3
4 files changed, 17 insertions, 4 deletions
diff --git a/Changelog-Trunk.txt b/Changelog-Trunk.txt
index 8ac5d590c..739e349a7 100644
--- a/Changelog-Trunk.txt
+++ b/Changelog-Trunk.txt
@@ -4,6 +4,7 @@ AS OF SVN REV. 5091, WE ARE NOW USING TRUNK. ALL UNTESTED BUGFIXES/FEATURES GO
IF YOU HAVE A WORKING AND TESTED BUGFIX PUT IT INTO STABLE AS WELL AS TRUNK.
2008/04/08
+ * Fixed party invitation ack messages not displaying (bugreport:1308)
* Modified PACKETVER for recent clients to use a YYYYMMDD date format
instead of a simple sequence number (allows adding versions inbetween)
2008/04/07
diff --git a/src/map/battle.c b/src/map/battle.c
index 1c52cbd4b..3702dc9d5 100644
--- a/src/map/battle.c
+++ b/src/map/battle.c
@@ -3662,7 +3662,7 @@ static const struct _battle_data {
{ "vending_tax", &battle_config.vending_tax, 0, 0, 10000, },
{ "day_duration", &battle_config.day_duration, 0, 0, INT_MAX, },
{ "night_duration", &battle_config.night_duration, 0, 0, INT_MAX, },
- { "mob_remove_delay", &battle_config.mob_remove_delay, 60000, 15000, INT_MAX, },
+ { "mob_remove_delay", &battle_config.mob_remove_delay, 60000, 1000, INT_MAX, },
{ "mob_active_time", &battle_config.mob_active_time, 0, 0, INT_MAX, },
{ "boss_active_time", &battle_config.boss_active_time, 0, 0, INT_MAX, },
{ "sg_miracle_skill_duration", &battle_config.sg_miracle_skill_duration, 3600000, 0, INT_MAX, },
diff --git a/src/map/clif.h b/src/map/clif.h
index c646e49ff..5a01e289a 100644
--- a/src/map/clif.h
+++ b/src/map/clif.h
@@ -35,7 +35,8 @@ struct guild;
// 6 - 2004-03-02aSakexe+ - 0x1f4, 0x1f5
// 7 - 2005-04-11aSakexe+ - 0x229, 0x22a, 0x22b, 0x22c
// 20070521 - 2007-05-21aSakexe+ - 0x283
-// 20070918 - 2007-09-18aSakexe+ - 0x2d6, 0x2d7, 0x2d8, 0x2d9, 0x2da
+// 20070821 - 2007-08-21aSakexe+ - 0x2c5
+// 20070918 - 2007-09-18aSakexe+ - 0x2d7, 0x2d9, 0x2da
// 20071106 - 2007-11-06aSakexe+ - 0x78, 0x7c, 0x22c
#ifndef PACKETVER
#define PACKETVER 20071106
diff --git a/src/map/clif.c b/src/map/clif.c
index 6f3dfd7e1..80edb3952 100644
--- a/src/map/clif.c
+++ b/src/map/clif.c
@@ -5361,7 +5361,10 @@ int clif_party_invite(struct map_session_data *sd,struct map_session_data *tsd)
}
/*==========================================
* Party invitation result. Flag values are:
* 0 -> char is already in a party
* 1 -> party invite was rejected
* 2 -> party invite was accepted
@@ -5374,11 +5377,19 @@ void clif_party_inviteack(struct map_session_data* sd, const char* nick, int fla
nullpo_retv(sd);
fd=sd->fd;
+#if PACKETVER < 20070821
WFIFOHEAD(fd,packet_len(0xfd));
WFIFOW(fd,0) = 0xfd;
safestrncpy((char*)WFIFOP(fd,2),nick,NAME_LENGTH);
WFIFOB(fd,26) = flag;
WFIFOSET(fd,packet_len(0xfd));
+#else
+ WFIFOHEAD(fd,packet_len(0x2c5));
+ WFIFOW(fd,0) = 0x2c5;
+ safestrncpy((char*)WFIFOP(fd,2),nick,NAME_LENGTH);
+ WFIFOL(fd,26) = flag;
+ WFIFOSET(fd,packet_len(0x2c5));
+#endif
}
/*==========================================
@@ -12389,7 +12400,7 @@ static int packetdb_readdb(void)
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0,191, 0, 0, 0, 0, 0, 0,
//#0x02C0
- 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+ 0, 0, 0, 0, 0, 30, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 6, -1, 10, 10, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
@@ -5361,7 +5361,10 @@ int clif_party_invite(struct map_session_data *sd,struct map_session_data *tsd)
}
/*==========================================
- * Party invitation result. Flag values are:
+ * Party invitation result.
+ * R 00fd <nick>.24S <flag>.B
+ * R 02c5 <nick>.24S <flag>.L
+ * Flag values are:
* 0 -> char is already in a party
* 1 -> party invite was rejected